pub enum BriteVerifyClientError {
MissingApiKey,
InvalidApiKey,
UnbuildableRequest(Error),
UnclonableRequest,
MismatchedVerificationResponse(Box<VerificationResponse>),
BulkListNotFound(Box<BulkListCRUDError>),
InvalidHeaderValue(InvalidHeaderValue),
InvalidBaseUrl(ParseError),
UnusableRequest(BriteVerifyTypeError),
UnusableResponse(Box<Response>),
Other(Error),
}Expand description
Errors encountered when building a
BriteVerifyClient
instance with a customized configuration
Variants
MissingApiKey
No API key provided when constructing a
BriteVerifyClient
instance
InvalidApiKey
The API key provided when constructing a
BriteVerifyClient
instance is either invalid or unauthorized
UnbuildableRequest(Error)
A request cannot be “built” for sending
UnclonableRequest
A request cannot be cloned when automatic rate-limit retry is enabled
MismatchedVerificationResponse(Box<VerificationResponse>)
The BriteVerify API responded to a single-transaction verification request with data that it shouldn’t have or omitted data it should have included
BulkListNotFound(Box<BulkListCRUDError>)
No bulk verification list exists for a given identifier
InvalidHeaderValue(InvalidHeaderValue)
Invalid or unusable API key provided when constructing
a BriteVerifyClient instance
InvalidBaseUrl(ParseError)
Invalid or unusable base url provided when constructing
a BriteVerifyClient instance
UnusableRequest(BriteVerifyTypeError)
A usable request could not be created
UnusableResponse(Box<Response>)
The BriteVerify API returned an unusable response (based on HTTP status code)
Other(Error)
A catch-all error for any other errors encountered