pub struct BulkPhoneNumberVerificationArray {
pub phone: String,
pub status: VerificationStatus,
pub phone_location: Option<String>,
pub secondary_status: Option<String>,
pub service_type: Option<String>,
}Expand description
The phone element of a bulk verification result
record returned by the BriteVerify API
Fields
phone: StringThe verified phone number
status: VerificationStatusThe phone number’s validity “status” (ref)
phone_location: Option<String>The geographical area within which the phone number was initially registered or should be considered “valid”
NOTE: from observed behavior, this field is never not
null
secondary_status: Option<String>The phone number’s “secondary” validity status
service_type: Option<String>The “type” of service the phone number most likely uses (e.g. “land line”, “mobile”, etc..)