AddressVerificationArray

Struct AddressVerificationArray 

pub struct AddressVerificationArray {
    pub address1: String,
    pub address2: Option<String>,
    pub city: String,
    pub state: String,
    pub zip: String,
    pub status: VerificationStatus,
    pub corrected: bool,
    pub errors: Vec<Value>,
    pub secondary_status: Option<String>,
}
The address element of a verification response

Fields

address1: String

The verified address’s street number and name

address2: Option<String>

Additional / supplemental delivery information (e.g. apartment, suite, or P.O. box number)

NOTE: from observed behavior, this field is always null, with the value from the original request sanitized, formatted, and appended to the value of address1. For example: request:

{
  "address1": "123 Main Street",
  "address2": "Suite 100",
  # ...
}

response:

{
  "address1": "123 Main St Ste 100",
  "address2": null,
  # ...
}
city: String

The verified address’s city or town

state: String

The verified address’s state or province

zip: String

The verified address’s ZIP or postal code

status: VerificationStatus

The validity “status” of the supplied street address (ref)

corrected: bool

Boolean flag indicating whether or not the supplied address was mutated by the BriteVerify API in the process of fulfilling the verification request.

NOTE: The BriteVerify API will mutate street address during validation in order to sanitize or “standardize” them. The BriteVerify API refers to this mutation as “correction”.

errors: Vec<Value>

A list of errors that were encountered while fulfilling the verification request

secondary_status: Option<String>

The “secondary” validity status of the supplied street address (ref).

NOTE: from observed behavior, this field does not appear in responses from the BriteVerify API’s single-transaction real-time endpoints. It does appear in responses from the bulk endpoints, but doesn’t appear to do so with appreciable frequency