pub struct EmailVerificationArray {
pub address: String,
pub account: String,
pub domain: String,
pub status: VerificationStatus,
pub connected: Option<Value>,
pub disposable: bool,
pub role_address: bool,
pub error_code: Option<VerificationError>,
pub error: Option<String>,
}Expand description
The email element of a verification response
Fields
address: StringThe full (original) IETF RFC 532 compliant email address
account: StringThe “account” portion of the verified email address
domain: StringThe “domain” portion of the verified email address
status: VerificationStatusThe validity “status” of the supplied email address [ref]
connected: Option<Value>The BriteVerify API docs don’t provide
any insight as to what the actual type
of connected might be other than to
notate that the “usual” value is null,
which briteverify-rs interprets as
“whatever it its, it’s nullable”.
disposable: boolBoolean flag indicating the whether or not the verified email address should be regarded as effectively ephemeral
role_address: boolBoolean flag indicating the whether or not the verified email address belongs to a “role” within an organization instead of belonging directly to a specific human
error_code: Option<VerificationError>The “formal” code representing any error(s) encountered by the BriteVerify API while verifying the email address [ref]
error: Option<String>The human-readable form of the response’s associated “formal” error code