pub struct PhoneNumberVerificationArray {
pub number: String,
pub status: VerificationStatus,
pub service_type: Option<String>,
pub phone_location: Option<Value>,
pub errors: Vec<Value>,
}Expand description
The phone element of a verification response
Fields
number: StringThe phone number from the originating verification request
NOTE: from observed behavior, this field will be the requested phone number, scrubbed of all non-numeric characters and formatted as:
"{country_code}{phone_number}"
status: VerificationStatusThe validity “status” of the supplied phone number (ref)
service_type: Option<String>The “type” of service the phone number most likely uses (e.g. “land line”, “mobile”, etc..)
phone_location: Option<Value>The geographical area within which the phone number was initially registered or should be considered “valid”
NOTE: from observed behavior, this field is never not
null
errors: Vec<Value>A list of errors that were encountered while fulfilling the verification request