VerificationRequest

Struct VerificationRequest 

pub struct VerificationRequest {
    pub email: Option<String>,
    pub phone: Option<String>,
    pub address: Option<StreetAddressArray>,
}
Request for verification made to one of the BriteVerify API’s single-transaction, real-time endpoints

Fields

email: Option<String>

The email address to be verified

phone: Option<String>

The phone number to be verified

address: Option<StreetAddressArray>

The street address to be verified

Implementations

Source

impl VerificationRequest

pub fn builder() -> VerificationRequestBuilder

Get an builder instance that can be used to build up a VerificationRequest incrementally

pub fn from_values<EmailAddress: ToString, PhoneNumber: ToString, AddressLine1: ToString, AddressLine2: ToString, CityName: ToString, StateNameOrAbbr: ToString, ZipCode: ToString>( email: Option<EmailAddress>, phone: Option<PhoneNumber>, address1: Option<AddressLine1>, address2: Option<AddressLine2>, city: Option<CityName>, state: Option<StateNameOrAbbr>, zip: Option<ZipCode>, ) -> Result<Self, BriteVerifyTypeError>

Create a new VerificationRequest instance from the supplied values